@@ -1,5 +1,5 @@
 package Util::Medley;
-$Util::Medley::VERSION = '0.053';
+$Util::Medley::VERSION = '0.054';
 use Modern::Perl;
 use Moose;
 
@@ -11,10 +11,10 @@ with
   'Util::Medley::Roles::Attributes::File::Zip',
   'Util::Medley::Roles::Attributes::Hash',
   'Util::Medley::Roles::Attributes::Hostname',
+  'Util::Medley::Roles::Attributes::Linux::PkgMgmt::RPM',
+  'Util::Medley::Roles::Attributes::Linux::PkgMgmt::YUM',
   'Util::Medley::Roles::Attributes::List',
   'Util::Medley::Roles::Attributes::Logger',
-  'Util::Medley::Roles::Attributes::PkgManager::RPM',
-  'Util::Medley::Roles::Attributes::PkgManager::YUM',
   'Util::Medley::Roles::Attributes::Spawn',
   'Util::Medley::Roles::Attributes::String',
   'Util::Medley::Roles::Attributes::XML';
@@ -25,7 +25,7 @@ Util::Medley - A collection of commonly used utilities.
 
 =head1 VERSION
 
-version 0.053
+version 0.054
 
 =head1 SYNOPSIS
 
@@ -68,6 +68,10 @@ interface to commonly used modules all under one roof.
 
 =item L<Util::Medley::File::Zip>
 
+=item L<Util::Medley::Linux::PkgMgmt::RPM>
+
+=item L<Util::Medley::Linux::PkgMgmt::YUM>
+
 =item L<Util::Medley::List>
 
 =item L<Util::Medley::Logger>
